@@ -5,17 +5,17 @@ if [ ! -d /Applications ]; then
     # Assumed to be Linux
 
     echo " *** Building static library using Linux-specific Makefile"
-#    make -f otherbuilds/Makefile.linux clean
+    make -f otherbuilds/Makefile.linux clean
     make -f otherbuilds/Makefile.linux
     
     echo " *** Linking against static library"
-    g++ main/main.cpp lib/librubberband.a -I. -Isrc -o test -lsndfile -lsamplerate -lpthread
+    g++ -std=c++11 main/main.cpp lib/librubberband.a -I. -Isrc -o test_static -lsndfile -lpthread
     
     echo " *** Running build from Linux-specific Makefile"
-    ./test -V
+    ./test_static -V
     
     echo " *** Building with single-file source"
-    g++ main/main.cpp single/RubberBandSingle.cpp -o test_single -lsndfile
+    g++ -O3 -std=c++11 main/main.cpp single/RubberBandSingle.cpp -o test_single -lsndfile
     
     echo " *** Running build from single-file source"
     ./test_single -V
@@ -29,13 +29,13 @@ else
     make -f otherbuilds/Makefile.macos
 
     echo " *** Linking against static library"
-    c++ main/main.cpp lib/librubberband.a -I. -Isrc -o test -lsndfile -lsamplerate -framework Accelerate
+    c++ -std=c++11 main/main.cpp lib/librubberband.a -I. -Isrc -o test_static -I/opt/homebrew/include -L/opt/homebrew/lib -lsndfile -framework Accelerate
     
     echo " *** Running build from macOS-specific Makefile"
-    ./test -V
+    ./test_static -V
 
     echo " *** Building with single-file source"
-c++ main/main.cpp single/RubberBandSingle.cpp -o test_single -lsndfile -framework Accelerate
+    c++ -O3 -std=c++11 main/main.cpp single/RubberBandSingle.cpp -o test_single -I/opt/homebrew/include -L/opt/homebrew/lib -lsndfile -framework Accelerate
 
     echo " *** Running build from single-file source"
     ./test_single -V
